==> haskell-chunked-data-0.3.1-299-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-chunked-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 chunked-data
version:              0.3.1
visibility:           public
id:                   chunked-data-0.3.1-6g1GaOyEfNwBhjcFHm0mr8
key:                  chunked-data-0.3.1-6g1GaOyEfNwBhjcFHm0mr8
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Typeclasses for dealing with various chunked data representations

description:
    See docs and README at <http://www.stackage.org/package/chunked-data>

category:             Data
abi:                  d34aea8a99a8d0b8fcc5d25551b04561
exposed:              True
exposed-modules:      Data.Builder Data.ChunkedZip Data.IOData
hidden-modules:       Paths_chunked_data
import-dirs:          /usr/lib/ghc-9.4.8/site-local/chunked-data-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/chunked-data-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/chunked-data-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-chunked-data
hs-libraries:         HSchunked-data-0.3.1-6g1GaOyEfNwBhjcFHm0mr8
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7 text-2.0.2
    transformers-0.5.6.2 vector-0.13.2.0-3KdUWUHYfVjDmpelwHDbn6

haddock-interfaces:
    /usr/share/doc/haskell-chunked-data/html/chunked-data.haddock

haddock-html:         /usr/share/doc/haskell-chunked-data/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-chunked-data-0.3.1-300-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-chunked-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 chunked-data
version:              0.3.1
visibility:           public
id:                   chunked-data-0.3.1-GNjHXo43O3pHv4A9xQqTgD
key:                  chunked-data-0.3.1-GNjHXo43O3pHv4A9xQqTgD
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Typeclasses for dealing with various chunked data representations

description:
    See docs and README at <http://www.stackage.org/package/chunked-data>

category:             Data
abi:                  98b6f932545934bdf939f5c17753185d
exposed:              True
exposed-modules:      Data.Builder Data.ChunkedZip Data.IOData
hidden-modules:       Paths_chunked_data
import-dirs:          /usr/lib/ghc-9.4.8/site-local/chunked-data-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/chunked-data-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/chunked-data-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-chunked-data
hs-libraries:         HSchunked-data-0.3.1-GNjHXo43O3pHv4A9xQqTgD
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7 text-2.0.2
    transformers-0.5.6.2 vector-0.13.2.0-ZKpjTfyjPa7BNElf7Ue7Z

haddock-interfaces:
    /usr/share/doc/haskell-chunked-data/html/chunked-data.haddock

haddock-html:         /usr/share/doc/haskell-chunked-data/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
